==> financial-front-2.0.1.tar.gz: financial-front-2.0.1/script/import_tdb.rb <==
# -*- coding: utf-8 -*-

# 信用調査データのインポート

require File.dirname(__FILE__) + '/import_common'
require 'csv'


REPORT_DAY = Date.new 2011, 2, 8


# CSVファイルと現在のテーブルの名前を並べて出力
def print_pairs
  data = sjis2utf8 File.read("tdb.csv")

  lineno = 0
  CSV::Reader.parse data do |line|
    lineno += 1
    next if lineno <= 1

    partner = Partner.find_by_zaimu_id line[153]
    partner = Partner.find_by_tdb_code line[0] if !partner

    if !partner
      print [line[153], "", line[4]].join("\t"), "\n"
    else
      print [partner.zaimu_id, partner.name, line[4]].join("\t"), "\n"
    end
  end
end


def import_tdb
  data = sjis2utf8(File.read("tdb.csv"))

  Partner.transaction {
    lineno = 0
    CSV::Reader.parse(data) {|line|
      lineno += 1
      next if lineno <= 1

      partner = Partner.find_by_zaimu_id(line[153])
      partner = Partner.find_by_tdb_code line[0] if !partner

      if !partner
        print [line[153], "", line[4]].join("\t"), "\n"

        partner = Partner.new :zaimu_id => line[153],
                        :tdb_code => line[0],
                        :name => normalize_kc(line[4].gsub(/[ 　\t\r\n]/, '')),
                        :kana_name => normalize_kc(line[2]),
                        :hq_zip => "#{line[5][0..2]}-#{line[5][3..6]}",
                        :hq_addr => line[8],
                        :industry => line[136],
                        :remarks => ''
        partner.save!
      else
        # 取引先データあり
        print [partner.zaimu_id, partner.name, line[4]].join("\t"), "\n"
        raise "partner_id = #{partner.id}" if partner.tdb_code && partner.tdb_code != line[0].to_i

        if partner.tdb_code != line[0] ||
             #  partner.name != normalize_kc(line[4].gsub(/[ 　\t\r\n]/, '')) ||
               partner.hq_zip != "#{line[5][0..2]}-#{line[5][3..6]}" ||
               partner.hq_addr != line[8] ||
               partner.industry != line[136]
          partner.attributes = {
                :tdb_code => line[0],
               # :name => normalize_kc(line[4].gsub(/[ 　\t\r\n]/, '')),
                :hq_zip => "#{line[5][0..2]}-#{line[5][3..6]}",
                :hq_addr => line[8],
                :industry => line[136],
                :updated_by => nil
          }
          partner.save!
        end
      end
    
      # 信用調査を追加
      ci = CreditInquiry.new :partner => partner,
                      :report_date => REPORT_DAY,
                      :score => line[21].to_i != 0 ? line[21] : nil,
                      :remarks => '',
                      :create_user_id => nil
      ci.save!
    }
  } # of transaction
end


print_pairs
#import_tdb

==> financial-front-2.99.0.tar.gz: financial-front-2.99.0/script/import_tdb.rb <==
# -*- coding: utf-8 -*-

# 信用調査データのインポート

require File.dirname(__FILE__) + '/import_common'
require 'csv'


#############################################################
# 設定

REPORT_DAY = Date.new 2013, 1, 31
FILE_NAME = "COSMS001.TXT"


#############################################################


# CSVファイルと現在のテーブルの名前を並べて出力
def print_pairs
  data = sjis2utf8 File.read(FILE_NAME)

  lineno = 0
  CSV::Reader.parse data do |line|
    lineno += 1
    next if lineno <= 1

    partner = Partner.find_by_zaimu_id line[153]
    partner = Partner.find_by_tdb_code line[0] if !partner

    if !partner
      print [line[153], "", line[4], line[0], "■"].join("\t"), "\n"
    else
      unmatch = norm(partner.name).gsub(/[ 　]/, "") !=
                              norm(line[4]).gsub(/[ 　]/, "") ? "■" : ""
      print [partner.zaimu_id, partner.name, line[4], line[0], unmatch].join("\t"), "\n"
    end
  end
end


def import_tdb
  data = sjis2utf8(File.read(FILE_NAME))

  Partner.transaction {
    lineno = 0
    CSV::Reader.parse(data) {|line|
      lineno += 1
      # next if lineno <= 1

      # まずTDBコードで探す
      partner = Partner.find_by_tdb_code line[0] 
      partner = Partner.find_by_zaimu_id(line[153]) if !partner

      if !partner
        print [line[153], "", line[4]].join("\t"), "\n"

        partner = Partner.new :zaimu_id => line[153],
                        :tdb_code => line[0],
                        :name => normalize_kc(line[4].gsub(/[ 　\t\r\n]/, '')),
                        :kana_name => normalize_kc(line[2]),
                        :hq_zip => "#{line[5][0..2]}-#{line[5][3..6]}",
                        :hq_addr => line[8],
                        :industry => line[136],
                        :remarks => ''
        partner.save!
      else
        # 取引先データあり
        print [partner.zaimu_id, partner.name, line[4]].join("\t"), "\n"
        raise "partner_id = #{partner.id}" if partner.tdb_code && partner.tdb_code != line[0].to_i

        if partner.tdb_code != line[0] ||
             #  partner.name != normalize_kc(line[4].gsub(/[ 　\t\r\n]/, '')) ||
               partner.hq_zip != "#{line[5][0..2]}-#{line[5][3..6]}" ||
               partner.hq_addr != line[8] ||
               partner.industry != line[136]
          partner.attributes = {
                :tdb_code => line[0],
               # :name => normalize_kc(line[4].gsub(/[ 　\t\r\n]/, '')),
                :hq_zip => "#{line[5][0..2]}-#{line[5][3..6]}",
                :hq_addr => line[8],
                :industry => line[136],
                :updated_by => nil
          }
          partner.save!
        end
      end
    
      # 信用調査を追加
      ci = CreditInquiry.new :partner => partner,
                      :report_date => REPORT_DAY,
                      :score => line[21].to_i != 0 ? line[21] : nil,
                      :remarks => '',
                      :create_user_id => nil
      ci.save!
    }
  } # of transaction
end


#print_pairs
import_tdb
